==> anfr-0.8.tar.gz: anfr-0.8/anfr/lib.py <==
# -*- coding: UTF-8 -*-
"""
  Main lib for ANFR Project

  Usage:
 
  >>> from anfr import proclamer
  >>> proclamer(data)
"""

import pandas as pd

__all__ = ['get_data']

def get_data(path_anfr, path_com):
  """
    Get cleaned version of ANFR data
  """
  # Import main dataframe
  df_anfr, df_com = import_data(path_anfr, path_com)
  df_merged = merge_data(df_anfr, df_com)
  df = clean_records(df_merged)
  return df

def import_data(path_anfr, path_com):
  # Import anfr .csv
  df_anfr = pd.read_csv(path_anfr,\
    sep=";",\
    usecols=['adm_lb_nom', 'generation', 'date_maj', 'code_insee', 'coordonnees', 'en_service'])
  df_anfr.columns = ['operator', 'insee', 'generation', 'updated_at', 'coordinates', 'status']
  df_anfr['insee'] = df_anfr['insee'].apply('{:0>5}'.format)
  df_anfr = df_anfr.sort_values(by='insee')
  df_anfr.head(5)
  # Import cities csv
  df_com = pd.read_csv(path_com,\
    sep=";",\
    usecols=['DEPCOM', 'COM', 'PTOT'])
  df_com.columns = ['insee', 'city', 'population']
  df_com = df_com.sort_values(by='insee')
  df_com.head(5)
  return df_anfr, df_com

def merge_data(df_anfr, df_com):
  #Merge antennas info with cities
  df_merged = df_anfr.merge(df_com, how='inner')
  return df_merged

def clean_records(df):
  # Split coordinates
  df[['latitude', 'longitude']] = df.coordinates.str.split(", ", expand=True)
  # Remove overseas cities
  df['latitude'] = df['latitude'].astype(float)
  df['longitude'] = df['longitude'].astype(float)
  df = df[df['latitude'].between(40, 52)]
  df = df[df['longitude'].between(-6, 10)]
  # Get per capita
  df['per_capita'] = df['population'] / df.groupby(['insee'])['insee'].transform('count')
  # Drop useless columns
  df_clean = df.drop(['coordinates'], axis=1)
  return df_clean

# if __name__ == '__main__':
#   p1 = '../data/anfr.csv'
#   p2 = '../data/communes.csv'
#   get_data(p1, p2)

==> anfr-0.10.tar.gz: anfr-0.10/anfr/lib.py <==
# -*- coding: UTF-8 -*-
"""
  Main lib for ANFR Project

  Usage:
 
  >>> from anfr import proclamer
  >>> proclamer(data)
"""

import pandas as pd

__all__ = ['get_base_data', 'get_top_exposed']

def get_base_data(path_anfr, path_com):
  """
    Get cleaned version of ANFR data
  """
  # Import main dataframe
  df_anfr, df_com = import_data(path_anfr, path_com)
  df_merged = merge_data(df_anfr, df_com)
  df = clean_records(df_merged)
  return df

def get_top_exposed(df, top="15", gen="4G"):
  # Getting data corresponding to generation
  df_exp = df[df['generation'] == gen]
  df_exp = df_exp[['city', 'population']]
  # Count entries for each city
  df_exp['per_capita'] = df_exp.groupby(['city'])['city'].transform('count')
  df_exp = df_exp.groupby(['city']).first().reset_index()
  # Group and sum parisian arrondissements together
  df_exp['city'] = df_exp['city'].apply(lambda x: 'Paris' if 'Paris ' in x else x)
  df_exp = df_exp.groupby(['city'])['population', 'per_capita'].sum().reset_index()
  # Count number of antennas for 1000 inhabitants
  df_exp['per_capita'] = round(df_exp['per_capita'] / df_exp['population'] * 1000, 1)
  # Sort
  df_exp = df_exp.sort_values(by=['population'], ascending=False)
  df_exp[:top].sort_values(by=['per_capita'], ascending=False)

def import_data(path_anfr, path_com):
  # Import anfr .csv
  df_anfr = pd.read_csv(path_anfr,\
    sep=";",\
    usecols=['adm_lb_nom', 'generation', 'date_maj', 'code_insee', 'coordonnees', 'en_service'])
  df_anfr.columns = ['operator', 'insee', 'generation', 'updated_at', 'coordinates', 'status']
  df_anfr['insee'] = df_anfr['insee'].apply('{:0>5}'.format)
  df_anfr = df_anfr.sort_values(by='insee')
  df_anfr.head(5)
  # Import cities csv
  df_com = pd.read_csv(path_com,\
    sep=";",\
    usecols=['DEPCOM', 'COM', 'PTOT'])
  df_com.columns = ['insee', 'city', 'population']
  df_com = df_com.sort_values(by='insee')
  df_com.head(5)
  return df_anfr, df_com

def merge_data(df_anfr, df_com):
  #Merge antennas info with cities
  df_merged = df_anfr.merge(df_com, how='inner')
  return df_merged

def clean_records(df):
  # Split coordinates
  df[['latitude', 'longitude']] = df.coordinates.str.split(", ", expand=True)
  # Remove overseas cities
  df['latitude'] = df['latitude'].astype(float)
  df['longitude'] = df['longitude'].astype(float)
  df = df[df['latitude'].between(40, 52)]
  df = df[df['longitude'].between(-6, 10)]
  # Get per capita
  df['per_capita'] = df['population'] / df.groupby(['insee'])['insee'].transform('count')
  # Drop useless columns
  df_clean = df.drop(['coordinates'], axis=1)
  return df_clean

# if __name__ == '__main__':
#   p1 = '../data/anfr.csv'
#   p2 = '../data/communes.csv'
#   get_data(p1, p2)
